@@ -657,7 +657,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/odr/matches/'
+        url = '/v1/odr/matches'
 
         if page is not None:
             url += f'?page={page}'
